@@ -154,7 +154,7 @@ def _make_homepage():
             "<h1>Circe</h1>"
             "<h2>API web pour la transformation de documents.</h2>"
             "<p>Voir documentation à "
-            '<a href="https://git.unicaen.fr/pdn-certic/circe">https://git.unicaen.fr/pdn-certic/circe</a>.</p>'
+            '<a href="https://git.unicaen.fr/fnso/i-fair-ir/circe-server">https://git.unicaen.fr/fnso/i-fair-ir/circe-server</a>.</p>'
         )
 
 
